@@ -48,7 +48,7 @@ class Service:
                 print ("{} {}".format (tc.debug (self.name), tc.secondary ("[stopped]")))
         return pid
 
-    def execute (self, cmd):
+    def execute (self, cmd, fallback_user = None):
         if cmd == "stop":
             self.stop ()
             return False
@@ -62,10 +62,10 @@ class Service:
             time.sleep (2)
             self.start ()
         elif cmd == "install":
-            self.install ()
+            self.install (fallback_user)
             return False
         elif cmd == "update":
-            self.update ()
+            self.update (fallback_user)
             return False
         elif cmd == "remove":
             self.remove ()
@@ -93,12 +93,15 @@ class Service:
             self.set_service_config (['update'])
 
     else:
-        def install (self, update = False):
+        def install (self, fallback_user, update = False):
             name = self.name.split ('/')[-1]
             service_script = '/etc/systemd/system/{}.service'.format (name)
             if not update and os.path.exists (service_script):
                 raise SystemError ('service {} is already exists. use update command'.format (name))
-            user = os.getenv("SUDO_USER") or os.getenv ("LOGNAME")
+            if fallback_user:
+                user = 'root'
+            else:
+                user = os.getenv("SUDO_USER") or os.getenv ("LOGNAME")
             args = sys.argv [1:]
             if args and hasattr (self, args [-1]):
                 args = args [:-1]
@@ -135,6 +138,9 @@ class Service:
 
             print ("  sudo systemctl start {}".format (name))
 
+        def update (self, fallback_user):
+            self.install (fallback_user, True)
+
         def remove (self):
             name = self.name.split ('/')[-1]
             service_script = '/etc/systemd/system/{}.service'.format (name)
@@ -142,9 +148,6 @@ class Service:
                 return
             os.remove (service_script)
 
-        def update (self):
-            self.install (True)
-
     uninstall = remove
 
 SERVICE_TEMPLATE = '''[Unit]
